==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm2015/lib/GeographicPolylineSeriesView_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { GeographicShapeSeriesBaseView } from "./GeographicShapeSeriesBaseView";
import { Defaults } from "igniteui-webcomponents-charts";
import { ScatterPolylineSeries } from "igniteui-webcomponents-charts";
import { markType, runOn, delegateCombine, markDep } from "igniteui-webcomponents-core";
import { GeographicShapeSeriesBase } from "./GeographicShapeSeriesBase";
import { StyleSelector } from "igniteui-webcomponents-charts";
import { DependencyProperty } from "igniteui-webcomponents-core";
import { Style } from "igniteui-webcomponents-core";
import { PropertyMetadata } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
export let GeographicPolylineSeriesView = /*@__PURE__*/ (() => {
    class GeographicPolylineSeriesView extends GeographicShapeSeriesBaseView {
        constructor(a) {
            super(a);
            this.cl = null;
            this.cl = a;
        }
        au() {
            super.au();
            if (!this.q) {
                this.cl.iv = Defaults.n;
            }
        }
        b5() {
            super.b5();
            this.cl.t5.wv = this.cl.vb;
            this.cl.t5.w0 = this.cl.vj;
        }
        cm() {
            this.cl.t5.wv = this.cl.vb;
        }
        cn() {
            this.cl.t5.w0 = this.cl.vj;
        }
    }
    GeographicPolylineSeriesView.$t = /*@__PURE__*/ markType(GeographicPolylineSeriesView, 'GeographicPolylineSeriesView', GeographicShapeSeriesBaseView.$);
    return GeographicPolylineSeriesView;
})();
/**
 * @hidden
 */
export let GeographicPolylineSeries = /*@__PURE__*/ (() => {
    class GeographicPolylineSeries extends GeographicShapeSeriesBase {
        bc() {
            return new GeographicPolylineSeries();
        }
        get_e5() {
            return true;
        }
        constructor() {
            super();
            this.styleShape = null;
            this.ab = GeographicPolylineSeries.$;
        }
        cd() {
            return new GeographicPolylineSeriesView(this);
        }
        o2(a) {
            super.o2(a);
            this.vc = a;
        }
        t4() {
            let a = new ScatterPolylineSeries();
            a.styleShape = delegateCombine(a.styleShape, runOn(this, this.vg));
            return a;
        }
        vg(a, b) {
            if (this.styleShape != null) {
                this.styleShape(this, b);
            }
        }
        pa(a, b, c, d) {
            super.pa(a, b, c, d);
            switch (b) {
                case GeographicPolylineSeries.$$p[1]:
                    this.vc.cm();
                    break;
                case GeographicPolylineSeries.$$p[0]:
                    this.vc.cn();
                    break;
            }
        }
    }
    GeographicPolylineSeries.$t = /*@__PURE__*/ markType(GeographicPolylineSeries, 'GeographicPolylineSeries', GeographicShapeSeriesBase.$);
    GeographicPolylineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, GeographicPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:vj:vh', [Style.$, null], 'ShapeStyleSelector:vb:vi', [StyleSelector.$, null]]);
    return GeographicPolylineSeries;
})();

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm2015/lib/GeographicPolylineSeriesView_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { GeographicShapeSeriesBaseView } from "./GeographicShapeSeriesBaseView";
import { Defaults } from "igniteui-webcomponents-charts";
import { ScatterPolylineSeries } from "igniteui-webcomponents-charts";
import { markType, runOn, delegateCombine, markDep } from "igniteui-webcomponents-core";
import { GeographicShapeSeriesBase } from "./GeographicShapeSeriesBase";
import { StyleSelector } from "igniteui-webcomponents-charts";
import { DependencyProperty } from "igniteui-webcomponents-core";
import { Style } from "igniteui-webcomponents-core";
import { PropertyMetadata } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
export let GeographicPolylineSeriesView = /*@__PURE__*/ (() => {
    class GeographicPolylineSeriesView extends GeographicShapeSeriesBaseView {
        constructor(a) {
            super(a);
            this.cp = null;
            this.cp = a;
        }
        ax() {
            super.ax();
            if (!this.r) {
                this.cp.jp = Defaults.n;
            }
        }
        b9() {
            super.b9();
            this.cp.w2.aaa = this.cp.yh;
            this.cp.w2.aaf = this.cp.yp;
        }
        cq() {
            this.cp.w2.aaa = this.cp.yh;
        }
        cr() {
            this.cp.w2.aaf = this.cp.yp;
        }
    }
    GeographicPolylineSeriesView.$t = /*@__PURE__*/ markType(GeographicPolylineSeriesView, 'GeographicPolylineSeriesView', GeographicShapeSeriesBaseView.$);
    return GeographicPolylineSeriesView;
})();
/**
 * @hidden
 */
export let GeographicPolylineSeries = /*@__PURE__*/ (() => {
    class GeographicPolylineSeries extends GeographicShapeSeriesBase {
        bk() {
            return new GeographicPolylineSeries();
        }
        get_fr() {
            return true;
        }
        constructor() {
            super();
            this.styleShape = null;
            this.ab = GeographicPolylineSeries.$;
        }
        ct() {
            return new GeographicPolylineSeriesView(this);
        }
        q1(a) {
            super.q1(a);
            this.yi = a;
        }
        w1() {
            let a = new ScatterPolylineSeries();
            a.styleShape = delegateCombine(a.styleShape, runOn(this, this.ym));
            return a;
        }
        ym(a, b) {
            if (this.styleShape != null) {
                this.styleShape(this, b);
            }
        }
        ra(a, b, c, d) {
            super.ra(a, b, c, d);
            switch (b) {
                case GeographicPolylineSeries.$$p[1]:
                    this.yi.cq();
                    break;
                case GeographicPolylineSeries.$$p[0]:
                    this.yi.cr();
                    break;
            }
        }
    }
    GeographicPolylineSeries.$t = /*@__PURE__*/ markType(GeographicPolylineSeries, 'GeographicPolylineSeries', GeographicShapeSeriesBase.$);
    GeographicPolylineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, GeographicPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:yp:yn', [Style.$, null], 'ShapeStyleSelector:yh:yo', [StyleSelector.$, null]]);
    return GeographicPolylineSeries;
})();
